Module batch

Module batch 

Structs

BatchParams
Parameters for batch computation of factor values over time series data.

Functions

run_graph
Executes batch factor computation on historical time series data.