Module batch
kunquant_
rs
0.1.0
Module batch
Module Items
Structs
Functions
In crate kunquant_
rs
kunquant_rs
Module
batch
Structs

Batch
Params
Parameters for batch computation of factor values over time series data.
Functions

run_
graph
Executes batch factor computation on historical time series data.